@@ -690,7 +690,8 @@ static void NewBlockDialog()
 	if ( !blockW ) {
 		ParamRegister( &blockPG );
 		blockW = ParamCreateDialog (&blockPG, MakeWindowTitle(_("Create Block")),
-		                            _("Ok"), BlockOk, wHide, TRUE, NULL, F_BLOCK, NULL );
+		                            _("Ok"), BlockOk, ParamCancel_Current,
+		                            TRUE, NULL, F_BLOCK, NULL );
 		blockD.dpi = mainD.dpi;
 	}
 	ParamLoadControls( &blockPG );
@@ -862,7 +863,7 @@ static void EditBlock (track_p trk)
 		blockEditW = ParamCreateDialog (&blockEditPG,
 		                                MakeWindowTitle(_("Edit block")),
 		                                _("Ok"), BlockEditOk,
-		                                wHide, TRUE, NULL, F_BLOCK,
+		                                ParamCancel_Current, TRUE, NULL, F_BLOCK,
 		                                NULL );
 	}
 	ParamLoadControls( &blockEditPG );
@@ -999,10 +1000,7 @@ static int BlockMgmProc ( int cmd, void * data )
 }
 
 
-//#include "bitmaps/blocknew.xpm"
-//#include "bitmaps/blockedit.xpm"
-//#include "bitmaps/blockdel.xpm"
-#include "bitmaps/block.xpm3"
+#include "bitmaps/block.image3"
 
 EXPORT void BlockMgmLoad( void )
 {
@@ -1010,7 +1008,7 @@ EXPORT void BlockMgmLoad( void )
 	static wIcon_p blockI = NULL;
 
 	if ( blockI == NULL) {
-		blockI = wIconCreatePixMap( block_xpm3[iconSize] );
+		blockI = wIconCreatePixMap( block_image3[iconSize] );
 	}
 
 	TRK_ITERATE(trk) {
@@ -1025,7 +1023,7 @@ EXPORT void InitCmdBlock( wMenu_p menu )
 	blockName[0] = '\0';
 	blockScript[0] = '\0';
 	AddMenuButton( menu, CmdBlockCreate, "cmdBlockCreate", _("Block"),
-	               wIconCreatePixMap( block_xpm3[iconSize] ), LEVEL0_50,
+	               wIconCreatePixMap( block_image3[iconSize] ), LEVEL0_50,
 	               IC_STICKY|IC_POPUP2, ACCL_BLOCK1, NULL );
 	ParamRegister( &blockPG );
 }
