@@ -487,7 +487,7 @@ static void EditControlDialog()
 		controlEditW = ParamCreateDialog (&controlEditPG,
 		                                  MakeWindowTitle(_("Edit control")),
 		                                  _("Ok"), ControlEditOk,
-		                                  wHide, TRUE, NULL,
+		                                  ParamCancel_Current, TRUE, NULL,
 		                                  F_BLOCK,
 		                                  NULL );
 	}
@@ -620,7 +620,7 @@ static int ControlMgmProc ( int cmd, void * data )
 	return FALSE;
 }
 
-#include "bitmaps/control.xpm3"
+#include "bitmaps/control.image3"
 
 EXPORT void ControlMgmLoad ( void )
 {
@@ -628,7 +628,7 @@ EXPORT void ControlMgmLoad ( void )
 	static wIcon_p controlI = NULL;
 
 	if (controlI == NULL) {
-		controlI = wIconCreatePixMap( control_xpm3[iconSize] );
+		controlI = wIconCreatePixMap( control_image3[iconSize] );
 	}
 
 	TRK_ITERATE(trk) {
@@ -642,7 +642,7 @@ EXPORT void ControlMgmLoad ( void )
 EXPORT void InitCmdControl ( wMenu_p menu )
 {
 	AddMenuButton( menu, CmdControl, "cmdControl", _("Control"),
-	               wIconCreatePixMap( control_xpm3[iconSize] ), LEVEL0_50, IC_STICKY|IC_POPUP2,
+	               wIconCreatePixMap( control_image3[iconSize] ), LEVEL0_50, IC_STICKY|IC_POPUP2,
 	               ACCL_CONTROL, NULL );
 }
 
