@@ -25,6 +25,7 @@
 #include "ccornu.h"
 #include "track.h"
 #include "draw.h"
+#include "include/toolbar.h"
 
 EXPORT DIST_T curBarScale = -1;
 EXPORT long hotBarLabels = 0;
@@ -87,7 +88,7 @@ static void HotBarHighlight( int inx, DIST_T fixed_x )
 	}
 	orig.y = 0;
 	size.x = hotBarMap(inx).w - 2.0/hotBarD.dpi;
-	size.y = toolbarHeight;
+	size.y = ToolbarGetHeight();
 #ifdef LATER
 	printf( "HotBarHilite fixed_x:%0.3f X0:%d/%0.3f X:%d/%0.3f+%0.3f X=%0.3f\n",
 	        fixed_x,
@@ -503,7 +504,7 @@ EXPORT void AddHotBarElement(
 }
 
 
-static void ChangeHotBar( long changes )
+EXPORT void ChangeHotBar( long changes )
 {
 #ifdef LATER
 	int curFileIndex = -3;
@@ -595,11 +596,11 @@ EXPORT void LayoutHotBar( void * redraw )
 	buttonWidth = wControlGetWidth((wControl_p)hotBarLeftB);
 	buttonHeight = wControlGetHeight((wControl_p)hotBarLeftB);
 	wControlSetPos( (wControl_p)hotBarLeftB, HOTBAR_LEFT,
-	                toolbarHeight+(hbHeight-buttonHeight)/2 );
+	                ToolbarGetHeight() +(hbHeight-buttonHeight)/2 );
 	wControlSetPos( (wControl_p)hotBarRightB, winWidth-20-buttonWidth+HOTBAR_LEFT+1,
-	                toolbarHeight+(hbHeight-buttonHeight)/2 );
+	                ToolbarGetHeight() +(hbHeight-buttonHeight)/2 );
 	wControlSetPos( (wControl_p)hotBarD.d, buttonWidth+HOTBAR_LEFT+1,
-	                toolbarHeight );
+	                ToolbarGetHeight());
 	wDrawSetSize( hotBarD.d, winWidth-20-buttonWidth*2, hbHeight+2, redraw );
 	hotBarD.size.x = ((double)(winWidth-20
 	                           -buttonWidth*2))/hotBarD.dpi*hotBarD.scale;
@@ -613,7 +614,7 @@ EXPORT void LayoutHotBar( void * redraw )
 	} else if (!redraw) {
 		RedrawHotBar( NULL, NULL, 0, 0 );
 	}
-	toolbarHeight += hbHeight+3;
+	ToolbarSetHeight( ToolbarGetHeight() + hbHeight+3 );
 }
 
 void HideHotBar( void )
