@@ -875,12 +875,12 @@ extendTrackUp:
  *
  */
 
-#include "bitmaps/extend.xpm3"
+#include "bitmaps/extend.image3"
 
 void InitCmdModify( wMenu_p menu )
 {
 	modifyCmdInx = AddMenuButton( menu, CmdModify, "cmdModify", _("Modify"),
-	                              wIconCreatePixMap(extend_xpm3[iconSize]), LEVEL0_50,
+	                              wIconCreatePixMap(extend_image3[iconSize]), LEVEL0_50,
 	                              IC_STICKY|IC_POPUP|IC_WANT_MOVE|IC_CMDMENU, ACCL_MODIFY, NULL );
 	/** @logcmd @showrefby modify=n cmodify.c Log Modify command */
 	log_modify = LogFindIndex( "modify" );
