@@ -854,7 +854,7 @@ static void UpdateCompound( track_p trk, int inx, descData_p descUpd,
 			DrawCompoundDescription( trk, &mainD, wDrawColorWhite );
 		}
 		/*sprintf( message, "%s\t%s\t%s", manufS, nameS, partnoS );*/
-		if (xx->title) { MyFree(xx->title); }
+		if (xx->title) { UndoDeferFree(xx->title); }
 		xx->title = newTitle;
 		xx->flipped = flipped;
 		xx->ungrouped = ungrouped;
@@ -1349,7 +1349,6 @@ BOOL_T ReadCompound(
 	char scale[10];
 	char *title;
 	wIndex_t layer;
-	char *cp;
 	long options = 0;
 	long position = 0;
 	long lineType = 0;
@@ -1389,15 +1388,6 @@ BOOL_T ReadCompound(
 			return FALSE;
 		}
 	}
-	if (paramVersion<6 && strlen( title ) > 2) {
-		cp = strchr( title, '\t' );
-		if (cp != NULL) {
-			cp = strchr( cp, '\t' );
-		}
-		if (cp == NULL) {
-			UpdateTitleMark( title, LookupScale(scale) );
-		}
-	}
 	trk = NewCompound( trkType, index, orig, angle, title, 0, NULL,
 	                   pathCnt > 1 ? pathPtr : NULL,
 	                   tempSegs_da.cnt, &tempSegs(0) );
