@@ -743,7 +743,9 @@ static void DoPrintMargin( void )
 	if ( customMarginWin == NULL ) {
 		int x=10, y=10;
 		customMarginWin = ParamCreateDialog( &customMarginPG,
-		                                     MakeWindowTitle(_("Print Margins")), _("Ok"), DoPrintMarginOk, NULL, TRUE,
+		                                     MakeWindowTitle(_("Print Margins")),
+		                                     _("Ok"), DoPrintMarginOk,
+		                                     ParamCancel_Null, TRUE,
 		                                     PrintMarginLayout, F_BLOCK, PrintMarginDlgUpdate );
 		if ( customMarginWin == NULL ) {
 			return;
@@ -1438,7 +1440,8 @@ static STATUS_T CmdPrint(
 			}
 			print_d.scale = printScale;
 			printWin = ParamCreateDialog( &printPG, MakeWindowTitle(_("Print")), _("Print"),
-			                              DoPrintPrint, (paramActionCancelProc)Reset, TRUE, NULL, 0, PrintDlgUpdate );
+			                              DoPrintPrint, ParamCancel_Reset,
+			                              TRUE, NULL, 0, PrintDlgUpdate );
 		}
 		sPrinterName = wPrintGetName();
 		while ( *sPrinterName == '\0' ) {
@@ -1560,7 +1563,7 @@ static STATUS_T CmdPrint(
 }
 
 
-#include "bitmaps/doc-print.xpm3"
+#include "bitmaps/doc-print.image3"
 
 EXPORT wIndex_t InitCmdPrint( wMenu_p menu )
 {
@@ -1572,7 +1575,7 @@ EXPORT wIndex_t InitCmdPrint( wMenu_p menu )
 	AddRotateMenu( printGridPopupM, PrintGridRotate );
 	ParamRegister( &customMarginPG );
 	return AddMenuButton( menu, CmdPrint, "cmdPrint", N_("Print..."),
-	                      wIconCreatePixMap(doc_print_xpm3[iconSize]), LEVEL0,
+	                      wIconCreatePixMap(doc_print_image3[iconSize]), LEVEL0,
 	                      IC_LCLICK|IC_POPUP3|IC_CMDMENU, ACCL_PRINT, NULL );
 }
 
