@@ -604,6 +604,7 @@ static void DoProfilePrint(void * junk)
 	wFont_p fp;
 	coOrd screenSize;
 	coOrd textsize;
+	double topMargin, rightMargin, bottomMargin, leftMargin;
 
 	if (!wPrintDocStart(_("Profile"), 1, &copies)) {
 		return;
@@ -614,6 +615,10 @@ static void DoProfilePrint(void * junk)
 	}
 	printProfileD.dpi = wDrawGetDPI(printProfileD.d);
 	wPrintGetPageSize(&w, &h);
+	wPrintGetMargins( &topMargin, &rightMargin,
+	                  &bottomMargin, &leftMargin );
+	w -= (leftMargin+rightMargin);
+	h -= (topMargin+bottomMargin);
 	printProfileD.orig.x = -PBL(printProfileFontSize);
 	printProfileD.orig.y = -PBB(printProfileFontSize);
 	printProfileD.angle = 0.0;
@@ -871,7 +876,7 @@ DoProfileReset(void *junk)
 static void
 DoProfileChange(void *junk)
 {
-	DestroyCopyOfProfileElements();
+	CreateCopyProfileElements();
 	TempRedraw();
 }
 
@@ -1440,7 +1445,7 @@ static STATUS_T CmdProfile(wAction_t action, coOrd pos)
 			labelH = textsize.y;
 			labelW = textsize.x;
 			profileW = ParamCreateDialog(&profilePG, MakeWindowTitle(_("Profile")), NULL,
-			                             NULL, wHide, TRUE, NULL, F_RESIZE, CloseProfileWindow);
+			                             NULL, ParamCancel_Undo, TRUE, NULL, F_RESIZE, CloseProfileWindow);
 		}
 		ParamLoadControls(&profilePG);
 		ParamGroupRecord(&profilePG);
@@ -1512,7 +1517,7 @@ static void ProfileChange(long changes)
 	}
 }
 
-#include "bitmaps/profile.xpm3"
+#include "bitmaps/profile.image3"
 
 EXPORT void InitCmdProfile(wMenu_p menu)
 {
@@ -1520,7 +1525,7 @@ EXPORT void InitCmdProfile(wMenu_p menu)
 	ParamRegister(&profilePG);
 
 	AddMenuButton(menu, CmdProfile, "cmdProfile", _("Profile"),
-	              wIconCreatePixMap(profile_xpm3[iconSize]), LEVEL0_50,
+	              wIconCreatePixMap(profile_image3[iconSize]), LEVEL0_50,
 	              IC_LCLICK|IC_CMDMENU|IC_POPUP3,
 	              ACCL_PROFILE, NULL);
 	profilePopupM = MenuRegister("Profile Mode");
