@@ -900,7 +900,7 @@ static STATUS_T CmdPull(
 
 
 
-#include "bitmaps/connect.xpm3"
+#include "bitmaps/connect.image3"
 
 wMenuPush_p pullConnectMultiple;
 
@@ -916,7 +916,7 @@ void pullMenuEnter( void * keyVP )
 void InitCmdPull( wMenu_p menu )
 {
 	AddMenuButton( menu, CmdPull, "cmdConnect", _("Connect Two Tracks"),
-	               wIconCreatePixMap(connect_xpm3[iconSize]), LEVEL0_50,
+	               wIconCreatePixMap(connect_image3[iconSize]), LEVEL0_50,
 	               IC_STICKY|IC_INITNOTSTICKY|IC_LCLICK|IC_POPUP3|IC_CMDMENU|IC_WANT_MOVE,
 	               ACCL_CONNECT, NULL );
 	pullPopupM = MenuRegister( "Connect Options" );
