@@ -667,8 +667,10 @@ static void EditAspectDialog ( wIndex_t inx )
 		signalAspectEditName[0] = '\0';
 		signalAspectEditScript[0] = '\0';
 	} else {
-		strncpy(signalAspectEditName,signalAspect(inx).aspectName,STR_SHORT_SIZE);
-		strncpy(signalAspectEditScript,signalAspect(inx).aspectScript,STR_LONG_SIZE);
+		strncpy(signalAspectEditName,signalAspect(inx).aspectName,STR_SHORT_SIZE-1);
+		signalAspectEditName[STR_SHORT_SIZE-1] = '\0';
+		strncpy(signalAspectEditScript,signalAspect(inx).aspectScript,STR_LONG_SIZE-1);
+		signalAspectEditScript[STR_LONG_SIZE-1] = '\0';
 	}
 	signalAspectEditIndex = inx;
 	if ( !aspectEditW ) {
@@ -676,7 +678,7 @@ static void EditAspectDialog ( wIndex_t inx )
 		aspectEditW = ParamCreateDialog (&aspectEditPG,
 		                                 MakeWindowTitle(_("Edit aspect")),
 		                                 _("Ok"), aspectEditOK,
-		                                 wHide, TRUE, NULL,F_BLOCK,NULL);
+		                                 ParamCancel_Current, TRUE, NULL,F_BLOCK,NULL);
 	}
 	ParamLoadControls( &aspectEditPG );
 	wShow( aspectEditW );
@@ -746,7 +748,8 @@ static void EditSignalDialog()
 		signalEditW = ParamCreateDialog (&signalEditPG,
 		                                 MakeWindowTitle(_("Edit signal")),
 		                                 _("Ok"), SignalEditOk,
-		                                 SignalEditCancel, TRUE, NULL,
+		                                 ParamCancel_Custom( SignalEditCancel ),
+		                                 TRUE, NULL,
 		                                 F_RESIZE|F_RECALLSIZE|F_BLOCK,
 		                                 SignalEditDlgUpdate );
 	}
@@ -757,7 +760,8 @@ static void EditSignalDialog()
 		DYNARR_RESET( signalAspect_p, signalAspect_da );
 	} else {
 		xx = GetsignalData ( signalEditTrack );
-		strncpy(signalEditName,xx->name,STR_SHORT_SIZE);
+		strncpy(signalEditName,xx->name,STR_SHORT_SIZE - 1);
+		signalEditName[STR_SHORT_SIZE - 1] = '\0';
 		signalEditHeadCount = xx->numHeads;
 		signalEditOrig = xx->orig;
 		signalEditAngle = xx->angle;
@@ -907,7 +911,7 @@ static int SignalMgmProc ( int cmd, void * data )
 	return FALSE;
 }
 
-#include "bitmaps/signal.xpm3"
+#include "bitmaps/signal.image3"
 
 EXPORT void SignalMgmLoad ( void )
 {
@@ -915,7 +919,7 @@ EXPORT void SignalMgmLoad ( void )
 	static wIcon_p signalI = NULL;
 
 	if (signalI == NULL) {
-		signalI = wIconCreatePixMap( signal_xpm3[iconSize] );
+		signalI = wIconCreatePixMap( signal_image3[iconSize] );
 	}
 
 	TRK_ITERATE(trk) {
@@ -929,7 +933,7 @@ EXPORT void SignalMgmLoad ( void )
 EXPORT void InitCmdSignal ( wMenu_p menu )
 {
 	AddMenuButton( menu, CmdSignal, "cmdSignal", _("Signal"),
-	               wIconCreatePixMap( signal_xpm3[iconSize] ), LEVEL0_50, IC_STICKY|IC_POPUP2,
+	               wIconCreatePixMap( signal_image3[iconSize] ), LEVEL0_50, IC_STICKY|IC_POPUP2,
 	               ACCL_SIGNAL, NULL );
 }
 
