@@ -646,7 +646,6 @@ static void StructureDlgUpdate(
 	curStructure = to;
 	ShowPierL();
 	RedrawStructure( structureD.d, NULL, 0, 0 );
-	/* ParamDialogOkActive( &structurePG, FALSE ); */
 }
 
 
@@ -985,7 +984,7 @@ EXPORT STATUS_T CmdStructureAction(
 		DYNARR_RESET(trkSeg_t,anchors_da);
 		Dst.state = 0;
 		InfoSubstituteControls( NULL, NULL );
-		HotBarCancel();
+		//HotBarCancel();
 		/*wHide( newTurn.reg.win );*/
 		return C_TERMINATE;
 
@@ -1028,11 +1027,13 @@ static STATUS_T CmdStructure(
 	case C_START:
 		if (structureW == NULL) {
 			structureW = ParamCreateDialog( &structurePG, MakeWindowTitle(_("Structure")),
-			                                _("Close"), (paramActionOkProc)DoStructOk, wHide, TRUE, NULL, F_RESIZE,
+			                                _("Close"), (paramActionOkProc)DoStructOk,
+			                                ParamCancel_Null, TRUE, NULL,
+			                                F_RESIZE,
 			                                StructureDlgUpdate );
 			RegisterChangeNotification( structureChange );
 		}
-		ParamDialogOkActive( &structurePG, FALSE );
+		ParamDialogOkActive( &structurePG, TRUE );
 		structureIndex = wListGetIndex( structureListL );
 		structurePtr = curStructure;
 		wShow( structureW );
@@ -1098,7 +1099,7 @@ static STATUS_T CmdStructure(
 
 	case C_CANCEL:
 		wHide( structureW );
-		return C_CANCEL;
+		return C_TERMINATE;
 
 	case C_REDRAW:
 	case C_TEXT:
@@ -1239,12 +1240,12 @@ static STATUS_T CmdStructureHotBar(
 	}
 }
 
-#include "bitmaps/building.xpm3"
+#include "bitmaps/building.image3"
 
 EXPORT void InitCmdStruct( wMenu_p menu )
 {
 	AddMenuButton( menu, CmdStructure, "cmdStructure", _("Structure"),
-	               wIconCreatePixMap(building_xpm3[iconSize]), LEVEL0_50,
+	               wIconCreatePixMap(building_image3[iconSize]), LEVEL0_50,
 	               IC_WANT_MOVE|IC_STICKY|IC_CMDMENU|IC_POPUP2, ACCL_STRUCTURE, NULL );
 	structureHotBarCmdInx = AddMenuButton( menu, CmdStructureHotBar,
 	                                       "cmdStructureHotBar", "", NULL, LEVEL0_50,
