@@ -221,9 +221,6 @@ static void DrawTurntable( track_p t, drawCmd_p d, wDrawColor color )
 		p0 = GetTrkEndPos( t, xx->currEp );
 		Translate( &p1, xx->pos, GetTrkEndAngle(t,xx->currEp)+180.0, xx->radius );
 	}
-	if (color == wDrawColorBlack) {
-		color = normalColor;
-	}
 	DrawArc( d, xx->pos, xx->radius, 0.0, 360.0, 0,
 	         (color == wDrawColorPreviewSelected
 	          || color == wDrawColorPreviewUnselected)?3:0, color );
@@ -1082,13 +1079,13 @@ static STATUS_T CmdTurntable( wAction_t action, coOrd pos )
 }
 
 
-#include "bitmaps/turntable.xpm3"
+#include "bitmaps/turntable.image3"
 
 
 EXPORT void InitCmdTurntable( wMenu_p menu )
 {
 	AddMenuButton( menu, CmdTurntable, "cmdTurntable", _("Custom Turntable"),
-	               wIconCreatePixMap(turntable_xpm3[iconSize]), LEVEL0_50,
+	               wIconCreatePixMap(turntable_image3[iconSize]), LEVEL0_50,
 	               IC_STICKY|IC_INITNOTSTICKY, ACCL_TURNTABLE, NULL );
 }
 
