@@ -32,7 +32,6 @@
 static paramIntegerRange_t i1_100 = { 1, 100 };
 static paramIntegerRange_t i0_256 = { 0, 256 };
 static paramIntegerRange_t i1_256 = { 1, 256 };
-static paramIntegerRange_t i1_1024 = { 1, 1024 };
 static paramIntegerRange_t i0_10000 = { 0, 10000 };
 static paramIntegerRange_t i0_99 = { 0, 99};
 static paramIntegerRange_t i1_1000 = { 1, 1000 };
@@ -51,6 +50,7 @@ static void UpdateChkPtInterval(long);
 static wIndex_t distanceFormatInx;
 
 EXPORT long enableBalloonHelp = 1;
+EXPORT long enableAudio = 1;
 
 EXPORT long showFlexTrack = 1;
 
@@ -67,18 +67,6 @@ long GetChanges( paramGroup_p pg )
 	return changes;
 }
 
-static paramGroup_t prefPG;
-
-
-
-
-
-static void OptionDlgCancel(
-        wWin_p win )
-{
-	wEnableBalloonHelp( (int)enableBalloonHelp );
-	wHide( win );
-}
 
 
 /****************************************************************************
@@ -199,7 +187,7 @@ static void DoDisplay( void * junk )
 {
 	if (displayW == NULL) {
 		displayW = ParamCreateDialog( &displayPG, MakeWindowTitle(_("Display Options")),
-		                              _("Ok"), DisplayOk, OptionDlgCancel, TRUE, NULL, 0, OptionDlgUpdate );
+		                              _("Ok"), DisplayOk, ParamCancel_Restore, TRUE, NULL, 0, OptionDlgUpdate );
 		wListAddValue( (wList_p)displayPLs[I_HOTBARLABELS].control, _("Proto"), NULL,
 		               I2VP(0x0002) );
 		wListAddValue( (wList_p)displayPLs[I_HOTBARLABELS].control, _("Proto/Manuf"),
@@ -284,7 +272,7 @@ static void DoCmdopt( void * junk )
 {
 	if (cmdoptW == NULL) {
 		cmdoptW = ParamCreateDialog( &cmdoptPG, MakeWindowTitle(_("Command Options")),
-		                             _("Ok"), CmdoptOk, OptionDlgCancel, TRUE, NULL, 0, OptionDlgUpdate );
+		                             _("Ok"), CmdoptOk, ParamCancel_Restore, TRUE, NULL, 0, OptionDlgUpdate );
 	}
 	ParamLoadControls( &cmdoptPG );
 	wShow( cmdoptW );
@@ -312,6 +300,7 @@ static char * unitsLabels[] = { N_("English"), N_("Metric"), NULL };
 static char * angleSystemLabels[] = { N_("Polar"), N_("Cartesian"), NULL };
 static char * enableBalloonHelpLabels[] = { N_("Balloon Help"), NULL };
 static char * enableFlexTrackLabels[] = { N_("Show FlexTrack in HotBar"), NULL };
+static char * enableAudioLabels[] = { N_("Enable audio signals"), NULL };
 static char * startOptions[] = { N_("Load Last Layout"), N_("Start New Layout"), NULL };
 
 static paramData_t prefPLs[] = {
@@ -327,13 +316,14 @@ static paramData_t prefPLs[] = {
 	{ PD_FLOAT, &turntableAngle, "turntable-angle", PDO_NOPSHUPD, &r0_180, N_("Turntable Angle") },
 	{ PD_LONG, &maxCouplingSpeed, "coupling-speed-max", PDO_NOPSHUPD, &i10_100, N_("Max Coupling Speed"), 0 },
 	{ PD_TOGGLE, &enableBalloonHelp, "balloonhelp", PDO_NOPSHUPD, enableBalloonHelpLabels, "", BC_HORZ },
+	{ PD_TOGGLE, &enableAudio, "setaudio", PDO_NOPSHUPD, enableAudioLabels, "", BC_HORZ },
 	{ PD_TOGGLE, &showFlexTrack, "showflextrack", PDO_NOPSHUPD, enableFlexTrackLabels, "", BC_HORZ},
 	{ PD_LONG, &dragPixels, "dragpixels", PDO_NOPSHUPD|PDO_DRAW, &i1_1000, N_("Drag Distance") },
 	{ PD_LONG, &dragTimeout, "dragtimeout", PDO_NOPSHUPD|PDO_DRAW, &i1_1000, N_("Drag Timeout") },
 	{ PD_LONG, &minGridSpacing, "mingridspacing", PDO_NOPSHUPD|PDO_DRAW, &i1_100, N_("Min Grid Spacing"), 0, 0 },
-#define I_CHKPT		(14)
+#define I_CHKPT		(15)
 	{ PD_LONG, &checkPtInterval, "checkpoint", PDO_NOPSHUPD|PDO_FILE, &i0_10000, N_("Check Point Frequency") },
-#define I_AUTOSAVE		(15)
+#define I_AUTOSAVE		(16)
 	{ PD_LONG, &autosaveChkPoints, "autosave", PDO_NOPSHUPD|PDO_FILE, &i0_99, N_("Autosave Checkpoint Frequency") },
 	{ PD_RADIO, &onStartup, "onstartup", PDO_NOPSHUPD, startOptions, N_("On Program Startup"), 0, NULL }
 };
@@ -504,6 +494,9 @@ static void PrefOk( void * junk )
 		NoticeMessage( MSG_ICON_SIZE_RESTART, _("Ok"), NULL ) ;
 	}
 
+	wPrefSetInteger("misc", "audio", enableAudio);
+	wSetAudio(enableAudio);
+
 	wHide( prefW );
 	DoChangeNotification(changes);
 }
@@ -514,7 +507,7 @@ static void DoPref( void * junk )
 {
 	if (prefW == NULL) {
 		prefW = ParamCreateDialog( &prefPG, MakeWindowTitle(_("Preferences")), _("Ok"),
-		                           PrefOk, wHide, TRUE, NULL, 0, OptionDlgUpdate );
+		                           PrefOk, ParamCancel_Restore, TRUE, NULL, 0, OptionDlgUpdate );
 		LoadDstFmtList();
 	}
 	ParamLoadControls( &prefPG );
@@ -561,7 +554,7 @@ static paramData_t colorPLs[] = {
 	{ PD_COLORLIST, &borderColor, "border", PDO_NOPSHUPD, NULL, N_("Border"), 0, I2VP(CHANGE_MAIN) },
 	{ PD_COLORLIST, &crossMajorColor, "crossmajor", PDO_NOPSHUPD, NULL, N_("Primary Axis"), 0, 0 },
 	{ PD_COLORLIST, &crossMinorColor, "crossminor", PDO_NOPSHUPD, NULL, N_("Secondary Axis"), 0, 0 },
-	{ PD_COLORLIST, &normalColor, "normal", PDO_NOPSHUPD, NULL, N_("Normal Track"), 0, I2VP(CHANGE_MAIN|CHANGE_PARAMS) },
+	{ PD_COLORLIST, &normalColor, "normal", PDO_NOPSHUPD, NULL, N_("Normal Track"), 0, I2VP(CHANGE_MAIN|CHANGE_PARAMS|CHANGE_MAP) },
 	{ PD_COLORLIST, &selectedColor, "selected", PDO_NOPSHUPD, NULL, N_("Selected Track"), 0, I2VP(CHANGE_MAIN) },
 	{ PD_COLORLIST, &profilePathColor, "profile", PDO_NOPSHUPD, NULL, N_("Profile Path"), 0, I2VP(CHANGE_MAIN) },
 	{ PD_COLORLIST, &exceptionColor, "exception", PDO_NOPSHUPD, NULL, N_("Exception Track"), 0, I2VP(CHANGE_MAIN) },
@@ -589,7 +582,7 @@ static void DoColor( void * junk )
 {
 	if (colorW == NULL) {
 		colorW = ParamCreateDialog( &colorPG, MakeWindowTitle(_("Color")), _("Ok"),
-		                            ColorOk, wHide, TRUE, NULL, 0, NULL );
+		                            ColorOk, ParamCancel_Restore, TRUE, NULL, 0, NULL );
 	}
 	ParamLoadControls( &colorPG );
 	wShow( colorW );
