@@ -53,7 +53,7 @@ static int keyState;
 static wBool_t gtkBlockEnabled = TRUE;
 static wBool_t maximize_at_next_show = FALSE;
 
-#include "../../bin/bitmaps/xtc.xpm"
+#include "bitmaps/xtc.image1"
 static GdkPixbuf *windowIconPixbuf = NULL;
 
 /*
@@ -305,7 +305,7 @@ void wWinSetSize(
 
 void wWinShow(
         wWin_p win,		/* Window */
-        wBool_t show)		/* Command */
+        unsigned show)		/* Command */
 {
 	//GtkRequisition min_req, pref_req;
 
@@ -318,7 +318,8 @@ void wWinShow(
 	}
 
 	int width, height;
-
+	show &= ~(DONTGRABFOCUS);	// flag is ignored on Linux
+	
 	if (show) {
 		keyState = 0;
 		getPos(win);
@@ -360,6 +361,7 @@ void wWinShow(
 		gtk_window_present(GTK_WINDOW(win->gtkwin));
 
 
+
 		gdk_window_raise(gtk_widget_get_window(win->gtkwin));
 
 		if (win->shown && win->modalLevel > 0) {
@@ -1049,7 +1051,7 @@ static wWin_p wWinCommonCreate(
 	}
 
 	if ( windowIconPixbuf == NULL ) {
-		windowIconPixbuf = gdk_pixbuf_new_from_xpm_data((const char**)&xtc_xpm);
+		windowIconPixbuf = gdk_pixbuf_new_from_inline(-1, (unsigned char *)xtc_image1, FALSE, NULL);
 	}
 	gtk_window_set_icon( GTK_WINDOW(w->gtkwin), windowIconPixbuf );
 
